@@ -85,7 +85,7 @@ Output the list, showing the empty entries, which could be filled with data.
     <BLANKLINE>
     # Magmav0.2 compatibility section
     list:
-     - "magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G"
+     - "magnet:?xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt"
     <BLANKLINE>
     
 And save it to a file with the empty entries cleaned away. 
@@ -97,7 +97,7 @@ Or just return a list of its files as MagmaFiles.
     
 Or output all magnet links inside the magma list. 
    >>> print mag.magnets
-   ['magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G']
+   ['magnet:?xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt']
   
   
 B{Reading from magma lists}
@@ -117,7 +117,7 @@ Get the first file from the list.
    
 And output its magnet. 
    >>> print one_file.magnet
-   magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
+   magnet:?xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt
    
 Or output all its (meta-) data. 
    >>> print one_file.data
@@ -126,7 +126,7 @@ Or output all its (meta-) data.
 
 Output all magnet links inside the magma list. 
    >>> print mag.magnets
-   ['magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G']
+   ['magnet:?xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt']
 
 Load a Magma object from a string containing Magma data via magma.load(). 
 As test, load a minimal Magma file, containing nothing but the header.
@@ -181,7 +181,7 @@ __copyright__ = 'Copyright (C) 2008 Arne Babenhauserheide'
 __date__ = '2008-05-09'
 __licence__ = 'GPL-3 or later'
 __program__ = 'MAGnet MAnifest Management'
-__version__ = '0.3.5'
+__version__ = '0.3.6'
 
 # The dependencies of the _init__ only. 
 __depends__ = ''
