@@ -39,57 +39,34 @@ from magma_list import Magma
 from magma_list import MagmaFile 
 
 
-def ask_audio(files, magma): 
-    """Ask, whether one of the files is an audio file."""
-    print "Now, let's make it a audio list."
-    print ""
-    audio = raw_input("Is one of the file a audio file (yes/No)? ")
-    # Ask until the user 
-    while not audio.lower() in ["yes", "no", "", "y", "n"]: 
-        audio = raw_input("Is one of the file a audio file? Please answer either 'yes' or 'no'. Just clicking enter skips: ")
-    # If we have no audio files, we return instantly. 
-    if audio.lower() == "no" or audio.lower() == "n" or audio.lower() == "": 
-        return 
-    
-    # Else, the answer was yes, and we can go on. 
-    # First get the file which is a audio file. TODO: Add support for multiple mutimedia files. 
-    
-    audio = raw_input("Please enter which file it is (1 or 2 or ...): ")
-    while not audio in [str(i) for i in range(1, len(magma.files) + 1)]: 
-        audio = raw_input("Please enter a valid number (1 or 2 or ...): ")
-    print "Now onwards to editing file", audio + ":", magma.files[int(audio) -1].name
-    file_to_edit = magma.files[int(audio) -1]
-    file_to_edit.path = files[int(audio) -1]
-    edit_file(file_to_edit)
-    
-    print "So now, the file looks like this:"
-    
-    print magma
-    
-    magma_filename = raw_input("Please enter a name to which to save the file. It should end on .magma: ")
-    magma.save(magma_filename)
-    
-    print "Magma file saved as", magma_filename
-    
-    print "It contains the following magnets:"
-    for i in magma.magnets: 
-        print i
-
-
 def edit_file(magma_file):
     """Edit the data inside a magma file - add metadata."""
     # First check, which metadata we can get automatically. 
     print "First this script will try to get some values automatically. "
     automatically_generated_tags = []
+    
+    if not magma_file.name.endswith(".mp3") or magma_file.name.endswith(".ogg"): 
+        print "No mp3 or ogg file. We only support mp3 and ogg vorbis at the moment."
+        return 
+    
     # Create the audio subdict
     magma_file.data["audio"] = {}
     try: 
         from tagpy import FileRef
         # The basic object from tagpy. 
         filetags = FileRef(magma_file.path)
+        print "yes, FileRef"
         # The object with audiodata. 
-        audioprops = filetags.audioProperties()
-        tagfile = filetags.file()
+        try: 
+            audioprops = filetags.audioProperties()
+        except: pass
+        try: 
+            tagfile = filetags.file()
+        except: pass
+        try: 
+            tag = filetags.tag()
+        except: pass
+        
         try: 
             # The length of time this file plays. 
             magma_file.data["audio"]["length-ms"] = audioprops.length*1000
@@ -110,28 +87,43 @@ def edit_file(magma_file):
             magma_file.data["size-Bytes"] = tagfile.length()
             automatically_generated_tags.append(("size-Bytes", magma_file.data["size-bits"]))
         except: pass
-    except: 
-        pass
+        
+        # Now to the general metatags of the file content. 
+        try: 
+            # The title of the file
+            magma_file.data["audio"]["title"] = tag.title
+            automatically_generated_tags.append(("title", magma_file.data["audio"]["title"]))
+        except: pass
+        
+        try: 
+            # The publish year of the file
+            magma_file.data["audio"]["year"] = tag.year
+            automatically_generated_tags.append(("year", magma_file.data["audio"]["year"]))
+        except: pass
+        
+        try: 
+            # The track number of the file
+            magma_file.data["audio"]["track"] = tag.track
+            automatically_generated_tags.append(("track", magma_file.data["audio"]["track"]))
+        except: pass
+        
+        try: 
+            # The genre of the file
+            magma_file.data["audio"]["genre"] = tag.genre
+            automatically_generated_tags.append(("genre", magma_file.data["audio"]["genre"]))
+        except: pass
+        
+        try: 
+            # The comment of the file
+            magma_file.data["audio"]["comment"] = tag.comment
+            automatically_generated_tags.append(("comment", magma_file.data["audio"]["comment"]))
+        except: pass
+    except: pass
     
     print "The following tags were added:"
     for i in automatically_generated_tags: 
         print i
-    # TODO: Ask the user which of the tags to add. 
     
-    magma_file.data["title"] = raw_input("Please enter the title of the file: ")
-    magma_file.data["description"] = raw_input("Please enter a description of the file: ")
-    
-    # Now add one of the artists. 
-    magma_file.data["audio"]["artists"]  = []
-    artist1 = {}
-    artist1["name"] = raw_input("Please enter the name of its artist: ")
-    artist1["website"] = raw_input("Please enter an url to the website of the artist: ")
-    magma_file.data["audio"]["artists"] .append(artist1)
-    
-    # And add some more data. 
-    magma_file.data["audio"]["album"] = raw_input("Please enter the name of the album: ")
-    magma_file.data["year"] = raw_input("Please enter the year when this work was published: ")
-    magma_file.data["audio"]["tracknumber"] = raw_input("Please enter the tracknumber of this file: ")
     
 
 
@@ -146,7 +138,34 @@ def create_magma_list_interactively(files):
     print "Basic magma list: "
     print magma
     
-    ask_audio(files, magma)
+    print "------ ------ ------ ------ ------ ------ "
+
+    print "Now we try add metadata using tagpy. "
+    for i in range(len(magma.files)): 
+        magma.files[i].path = files[i]
+        edit_file(magma.files[i])
+    
+    print "------ ------ ------ ------ ------ ------ "
+    print "The magma list now looks like this: "
+    print magma
+    
+    ip_port = raw_input("If you use Gnutella, you can now give a list of IP:PORT pairs seperated by spaces as alternate-locations: ")
+    alt_locs = ip_port.split()
+    
+    try: 
+        from IPy import IP
+        for i in alt_locs: 
+            ip = IP(i.split(":")[0])
+    
+        if len(alt_locs) > 0: 
+            for i in magma.files: 
+                i.data["gnutella"]["alt-locs"] = alt_locs
+    except: 
+        print "You need the IPy module to add alt-locs, and the IP addresses need to be valid. No alt-locs added."
+        print "To fix it just run 'easy_install IPy', and check the format of the IPs"
+    
+    target_file = raw_input("Where shall we save it? ")
+    magma.save(target_file)
     
     
 
