@@ -308,6 +308,7 @@ class MagmaFile(object):
 
     
     """
+    
     def __init__(self, data, *args, **kwds):
         """A file inside the magma list. 
         
@@ -324,8 +325,7 @@ class MagmaFile(object):
         self.urls = self.readout_urls()
         #: The Other Gnutella clients who have the file. 
         self.Gnutella_alt_locs = self.readout_gnet_alt_locs()
-        #: The magnet link of the file
-        self.magnet = self.parse_magnet()
+        
     
     def __str__(self): 
         """Show nicely readable information about the file.
@@ -374,7 +374,17 @@ class MagmaFile(object):
         xt = "urn:sha1:" + self.sha1_hash
         # And from it we get dn
         dn = self.name
-        params = {"xt": xt, "dn": dn}
+        
+        # Now we get our url parameters. 
+        params = [("xt", xt ), ("dn", dn )]
+        
+        # Additionally we want to add alt-locs. 
+        gnet_alt_locs = self.readout_gnet_alt_locs()
+        # They need to be transformed to the correct xs parameter, though. 
+        for i in gnet_alt_locs: 
+            params.append(("xs", "http://" + str(i) + "/uri-res/N2R?" + xt))
+            
+        
         # Now get the urlencode method
         from urllib import urlencode
         #: The magnet link is a String. 
@@ -382,6 +392,8 @@ class MagmaFile(object):
         # TODO: Include alt-locs. 
         return magnet
     
+    #: The magnet link of the file
+    magnet = property(fget=parse_magnet, fset=setattr)
     
     def remove_empty_entries(self): 
         """Remove empty entries from the file, for example empty alt-locs."""
@@ -409,7 +421,6 @@ class MagmaFile(object):
                 pass
         #TODO: Make this rekursive, so we can clean arbitrary deeply nested structures. 
 
-
 def usage(): 
     """Usage instructions.
     
